==> lucide_py-0.1.0-py3-none-any.whl: lucide/icons/building.py <==
from .. import IconBase


class IconBuilding(IconBase):
    class_name = "lucide lucide-building"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "rect": {
                "width": "16",
                "height": "20",
                "x": "4",
                "y": "2",
                "rx": "2",
                "ry": "2"
            }
        },
        {
            "path": {
                "d": "M9 22v-4h6v4"
            }
        },
        {
            "path": {
                "d": "M8 6h.01"
            }
        },
        {
            "path": {
                "d": "M16 6h.01"
            }
        },
        {
            "path": {
                "d": "M12 6h.01"
            }
        },
        {
            "path": {
                "d": "M12 10h.01"
            }
        },
        {
            "path": {
                "d": "M12 14h.01"
            }
        },
        {
            "path": {
                "d": "M16 10h.01"
            }
        },
        {
            "path": {
                "d": "M16 14h.01"
            }
        },
        {
            "path": {
                "d": "M8 10h.01"
            }
        },
        {
            "path": {
                "d": "M8 14h.01"
            }
        }
    ]
}

==> lucide_py-0.1.1-py3-none-any.whl: lucide/icons/building.py <==
from .. import IconBase


class IconBuilding(IconBase):
    class_name = "lucide lucide-building"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "view_box": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "rect": {
                "width": "16",
                "height": "20",
                "x": "4",
                "y": "2",
                "rx": "2",
                "ry": "2"
            }
        },
        {
            "path": {
                "d": "M9 22v-4h6v4"
            }
        },
        {
            "path": {
                "d": "M8 6h.01"
            }
        },
        {
            "path": {
                "d": "M16 6h.01"
            }
        },
        {
            "path": {
                "d": "M12 6h.01"
            }
        },
        {
            "path": {
                "d": "M12 10h.01"
            }
        },
        {
            "path": {
                "d": "M12 14h.01"
            }
        },
        {
            "path": {
                "d": "M16 10h.01"
            }
        },
        {
            "path": {
                "d": "M16 14h.01"
            }
        },
        {
            "path": {
                "d": "M8 10h.01"
            }
        },
        {
            "path": {
                "d": "M8 14h.01"
            }
        }
    ]
}
